/***************************************************************************
**
** Copyright (C) 2017 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the examples of the QtBluetooth module of the Qt Toolkit.
**
**$QT_BEGIN_LICENSE:BSD$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** BSD License Usage
** Alternatively, you may use this file under the terms of the BSD license
** as follows:
**
** "Redistribution and use in source and binary forms, with or without
** modification, are permitted provided that the following conditions are
** met:
**   * Redistributions of source code must retain the above copyright
**     notice, this list of conditions and the following disclaimer.
**   * Redistributions in binary form must reproduce the above copyright
**     notice, this list of conditions and the following disclaimer in
**     the documentation and/or other materials provided with the
**     distribution.
**   * Neither the name of The Qt Company Ltd nor the names of its
**     contributors may be used to endorse or promote products derived
**     from this software without specific prior written permission.
**
**
** THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
** "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
** LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
** A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
** OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
** SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
** LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
** DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
** THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
** (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
** OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE."
**
** $QT_END_LICENSE$
**
****************************************************************************/

pragma Singleton
import QtQuick 2.5
import "./Dark.js" as Dark
import "./Light.js" as Light
import "./Default.js" as Default

Item {
    property int wHeight
    property int wWidth
    property var theme: Default

    // Colors
    readonly property color backgroundColor:  theme.backgroundColor

    // buttons
    readonly property color buttonColor:  theme.buttonColor
    readonly property color buttonPressedColor:  theme.buttonPressedColor
    readonly property color buttonBorderColor:  theme.buttonBorderColor
    readonly property color disabledButtonColor:  theme.disabledButtonColor

    readonly property color viewColor:  theme.viewColor
    readonly property color menuColor: theme.menuColor

    //delegates
    readonly property color delegate1Color:  theme.delegate1Color
    readonly property color delegate2Color:  theme.delegate2Color

    //text
    readonly property color textColor:  theme.textColor
    readonly property color textDarkColor:  theme.textDarkColor
    readonly property color disabledTextColor:  theme.disabledTextColor

    readonly property color sliderColor:  theme.sliderColor

    readonly property color errorColor:  theme.errorColor
    readonly property color infoColor:  theme.infoColor

    readonly property color lineColor:  theme.lineColor

    // Icons
    readonly property string backIcon:  theme.backIcon
    readonly property string settIcon:  theme.settIcon

    // Font sizes
    property real microFontSize: hugeFontSize * 0.2
    property real tinyFontSize: hugeFontSize * 0.4
    property real smallTinyFontSize: hugeFontSize * 0.5
    property real smallFontSize: hugeFontSize * 0.6
    property real mediumFontSize: hugeFontSize * 0.7
    property real bigFontSize: hugeFontSize * 0.8
    property real largeFontSize: hugeFontSize * 0.9
    property real hugeFontSize: (wWidth + wHeight) * 0.03
    property real giganticFontSize: (wWidth + wHeight) * 0.04

    // Some other values
    property real fieldHeight: wHeight * 0.08
    property real fieldMargin: fieldHeight * 0.5
    property real buttonHeight: wHeight * 0.08
    property real buttonRadius: buttonHeight * 0.1

    function refreshTheme(){
        switch(_cppAppSettings.loadSetting("theme")){
            case "Dark":
            theme = Dark
            break
            case "Light":
            theme = Light
            break
        }
    }



    // Some help functions
    function widthForHeight(h, ss)
    {
        return h/ss.height * ss.width;
    }

    function heightForWidth(w, ss)
    {
        return w/ss.width * ss.height;
    }

    function setTheme()
    {
        switch(_cppAppSettings.loadSetting("theme")){
            case "Dark":
                _cppAppSettings.writeSetting("theme", "Light")
                theme = Light
            break
            case "Light":
                _cppAppSettings.writeSetting("theme", "Dark")
                theme = Dark
            break
        }
    }

}
